package
Version:
v1.0.2
Opens a new window with list of versions in this module.
Published: Jul 10, 2026
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func New() (pdfFile, error)
New creates a PDF writer that preserves original image data and uses each
image's dimensions for its page size.
Open creates a reader for PDF files containing one embedded image per page.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.